@@ -7,7 +7,9 @@ import six
 
 class ValueConverter(BaseValueConverter):
     def to_python(self, value):
-        if isinstance(value, six.string_types) and not value:
+        if isinstance(value, six.string_types) \
+                and self._has_default \
+                and not value:
             return self.get_default()
 
         return six.text_type(value)
